module AboutYou
  module SDK
    ###
    # The CacheProvider namespace
    ###
    module CacheProvider
      ###
      # This class is used as an interface for cache operations.
      # It is used when caching with Dalli.
      #
      # author:: Collins GmbH & Co KG
      ###
      class Dalli
        require 'dalli'

        # an instance of the cache client.
        attr_accessor :client

        ###
        # the Constructor for the Dalli class
        #
        # * *Args*    :
        #   - +client+ -> an instance of Dalli::Client
        #
        # * *Returns* :
        #   - Instance of AboutYou::SDK::CacheProvider::Dalli
        ###
        def initialize(client)
          self.client = client
        end

        ###
        # This method is used for setting new cache entries with Dalli.
        #
        # * *Args*    :
        #   - +key+ -> The key of the cache entry
        #   - +value+ -> The value of the cache entry
        #   - +duration+ -> the duration of the cache entry
        #
        # * *Returns* :
        #   - True/False determining whether the setting was successful of not
        ###
        def set(key, value, duration)
          client.set(key, value, duration)
        end

        ###
        # This method is used for getting cache entries with Dalli.
        #
        # * *Args*    :
        #   - +key+ -> The key of the cache entry
        #
        # * *Returns* :
        #   - Either the value for the given key or nil if the key was not found
        ###
        def get(key)
          client.get(key)
        end

        ###
        # This method is used for deleting cache entries with Dalli.
        #
        # * *Args*    :
        #   - +key+ -> The key of the cache entry
        #
        # * *Returns* :
        #   - True/False determining whether the deletion was successful or not
        ###
        def delete(key)
          client.delete(key)
        end

        ###
        # This method is used for checking whether a cache entry exists or not with Dalli.
        #
        # * *Args*    :
        #   - +key+ -> The key of the cache entry
        #
        # * *Returns* :
        #   - True/False determining whether the key exists in the cache or not
        ###
        def exists(key)
          !client.get(key).nil?
        end
      end
    end
  end
end
